# <img src="https://graph.org/file/567afbf357f1ecbe98376.png" alt="seedr" height="30px"> Seedr API

### Unofficial API wrapper for seedr.cc <br> Inspired by [theabbie](https://github.com/theabbie)'s [**seedr-api**](https://github.com/theabbie/seedr-api)

## Docs & Examples
Please go to [wiki](https://github.com/AnjanaMadu/SeedrAPI/wiki/)

## Credits
- [theabbie](https://github.com/theabbie) for his [seedr-api](https://github.com/theabbie/seedr-api)
- [me](https://github.com/AnjanaMadu) for nothing

## Issues
- Open a [issue](https://github.com/AnjanaMadu/SeedrAPI/issues)
- Contact me on [telegram](https://t.me/Anjana_Ma)
